@@ -1,10 +1,10 @@
 from __future__ import annotations
 
-from ctypes import PYFUNCTYPE, Structure, c_char_p, c_int, c_void_p, py_object
+from ctypes import PYFUNCTYPE, c_char_p, c_int, c_void_p, py_object
 
 from typing_extensions import Annotated
 
-from einspect.structs import struct
+from einspect.structs.deco import Struct
 
 __all__ = ("getter", "setter", "PyMemberDef", "PyGetSetDef")
 
@@ -12,8 +12,7 @@ getter = PYFUNCTYPE(py_object, py_object, py_object)
 setter = PYFUNCTYPE(c_int, py_object, py_object, c_void_p)
 
 
-@struct
-class PyMemberDef(Structure):
+class PyMemberDef(Struct):
     name: c_char_p
     type: Annotated[int, c_int]
     offset: int
@@ -21,8 +20,7 @@ class PyMemberDef(Structure):
     doc: c_char_p
 
 
-@struct
-class PyGetSetDef(Structure):
+class PyGetSetDef(Struct):
     name: c_char_p
     get: getter
     set: setter
